from synctera_client.paths.monitoring_alerts_alert_id.get import ApiForget
from synctera_client.paths.monitoring_alerts_alert_id.patch import ApiForpatch


class MonitoringAlertsAlertId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class CardTransactionData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Transaction metadata specific to transactions with type `CARD`
    """


    class MetaOapg:
        
        class properties:
            card_id = schemas.UUIDSchema
            currency_code = schemas.StrSchema
            
            
            class currency_conversion(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        conversion_rate = schemas.NumberSchema
                        original_amount = schemas.IntSchema
                        original_currency_code = schemas.StrSchema
                        __annotations__ = {
                            "conversion_rate": conversion_rate,
                            "original_amount": original_amount,
                            "original_currency_code": original_currency_code,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["conversion_rate"]) -> MetaOapg.properties.conversion_rate: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["original_amount"]) -> MetaOapg.properties.original_amount: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["original_currency_code"]) -> MetaOapg.properties.original_currency_code: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["conversion_rate", "original_amount", "original_currency_code", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["conversion_rate"]) -> typing.Union[MetaOapg.properties.conversion_rate, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["original_amount"]) -> typing.Union[MetaOapg.properties.original_amount, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["original_currency_code"]) -> typing.Union[MetaOapg.properties.original_currency_code, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["conversion_rate", "original_amount", "original_currency_code", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    conversion_rate: typing.Union[MetaOapg.properties.conversion_rate, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
                    original_amount: typing.Union[MetaOapg.properties.original_amount, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    original_currency_code: typing.Union[MetaOapg.properties.original_currency_code, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'currency_conversion':
                    return super().__new__(
                        cls,
                        *_args,
                        conversion_rate=conversion_rate,
                        original_amount=original_amount,
                        original_currency_code=original_currency_code,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class merchant(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        address = schemas.StrSchema
                        city = schemas.StrSchema
                        country_code = schemas.StrSchema
                        independent_sales_organization_id = schemas.StrSchema
                        mcc = schemas.StrSchema
                        mid = schemas.StrSchema
                        name = schemas.StrSchema
                        payment_facilitator_id = schemas.StrSchema
                        postal_code = schemas.StrSchema
                        state = schemas.StrSchema
                        sub_merchant_id = schemas.StrSchema
                        __annotations__ = {
                            "address": address,
                            "city": city,
                            "country_code": country_code,
                            "independent_sales_organization_id": independent_sales_organization_id,
                            "mcc": mcc,
                            "mid": mid,
                            "name": name,
                            "payment_facilitator_id": payment_facilitator_id,
                            "postal_code": postal_code,
                            "state": state,
                            "sub_merchant_id": sub_merchant_id,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["city"]) -> MetaOapg.properties.city: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["country_code"]) -> MetaOapg.properties.country_code: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["independent_sales_organization_id"]) -> MetaOapg.properties.independent_sales_organization_id: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["mcc"]) -> MetaOapg.properties.mcc: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["mid"]) -> MetaOapg.properties.mid: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["payment_facilitator_id"]) -> MetaOapg.properties.payment_facilitator_id: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["postal_code"]) -> MetaOapg.properties.postal_code: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["state"]) -> MetaOapg.properties.state: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["sub_merchant_id"]) -> MetaOapg.properties.sub_merchant_id: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "city", "country_code", "independent_sales_organization_id", "mcc", "mid", "name", "payment_facilitator_id", "postal_code", "state", "sub_merchant_id", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["city"]) -> typing.Union[MetaOapg.properties.city, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["country_code"]) -> typing.Union[MetaOapg.properties.country_code, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["independent_sales_organization_id"]) -> typing.Union[MetaOapg.properties.independent_sales_organization_id, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["mcc"]) -> typing.Union[MetaOapg.properties.mcc, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["mid"]) -> typing.Union[MetaOapg.properties.mid, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["payment_facilitator_id"]) -> typing.Union[MetaOapg.properties.payment_facilitator_id, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["postal_code"]) -> typing.Union[MetaOapg.properties.postal_code, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["state"]) -> typing.Union[MetaOapg.properties.state, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["sub_merchant_id"]) -> typing.Union[MetaOapg.properties.sub_merchant_id, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "city", "country_code", "independent_sales_organization_id", "mcc", "mid", "name", "payment_facilitator_id", "postal_code", "state", "sub_merchant_id", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
                    city: typing.Union[MetaOapg.properties.city, str, schemas.Unset] = schemas.unset,
                    country_code: typing.Union[MetaOapg.properties.country_code, str, schemas.Unset] = schemas.unset,
                    independent_sales_organization_id: typing.Union[MetaOapg.properties.independent_sales_organization_id, str, schemas.Unset] = schemas.unset,
                    mcc: typing.Union[MetaOapg.properties.mcc, str, schemas.Unset] = schemas.unset,
                    mid: typing.Union[MetaOapg.properties.mid, str, schemas.Unset] = schemas.unset,
                    name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                    payment_facilitator_id: typing.Union[MetaOapg.properties.payment_facilitator_id, str, schemas.Unset] = schemas.unset,
                    postal_code: typing.Union[MetaOapg.properties.postal_code, str, schemas.Unset] = schemas.unset,
                    state: typing.Union[MetaOapg.properties.state, str, schemas.Unset] = schemas.unset,
                    sub_merchant_id: typing.Union[MetaOapg.properties.sub_merchant_id, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'merchant':
                    return super().__new__(
                        cls,
                        *_args,
                        address=address,
                        city=city,
                        country_code=country_code,
                        independent_sales_organization_id=independent_sales_organization_id,
                        mcc=mcc,
                        mid=mid,
                        name=name,
                        payment_facilitator_id=payment_facilitator_id,
                        postal_code=postal_code,
                        state=state,
                        sub_merchant_id=sub_merchant_id,
                        _configuration=_configuration,
                        **kwargs,
                    )
            network = schemas.StrSchema
            network_reference_id = schemas.StrSchema
            
            
            class pos(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        card_data_input_capability = schemas.StrSchema
                        card_holder_presence = schemas.BoolSchema
                        card_presence = schemas.BoolSchema
                        cardholder_authentication_method = schemas.StrSchema
                        country_code = schemas.StrSchema
                        is_installment = schemas.BoolSchema
                        is_recurring = schemas.BoolSchema
                        pan_entry_mode = schemas.StrSchema
                        partial_approval_capable = schemas.BoolSchema
                        pin_entry_mode = schemas.StrSchema
                        pin_present = schemas.BoolSchema
                        purchase_amount_only = schemas.BoolSchema
                        terminal_attendance = schemas.StrSchema
                        terminal_id = schemas.StrSchema
                        terminal_location = schemas.StrSchema
                        terminal_type = schemas.StrSchema
                        zip = schemas.StrSchema
                        __annotations__ = {
                            "card_data_input_capability": card_data_input_capability,
                            "card_holder_presence": card_holder_presence,
                            "card_presence": card_presence,
                            "cardholder_authentication_method": cardholder_authentication_method,
                            "country_code": country_code,
                            "is_installment": is_installment,
                            "is_recurring": is_recurring,
                            "pan_entry_mode": pan_entry_mode,
                            "partial_approval_capable": partial_approval_capable,
                            "pin_entry_mode": pin_entry_mode,
                            "pin_present": pin_present,
                            "purchase_amount_only": purchase_amount_only,
                            "terminal_attendance": terminal_attendance,
                            "terminal_id": terminal_id,
                            "terminal_location": terminal_location,
                            "terminal_type": terminal_type,
                            "zip": zip,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["card_data_input_capability"]) -> MetaOapg.properties.card_data_input_capability: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["card_holder_presence"]) -> MetaOapg.properties.card_holder_presence: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["card_presence"]) -> MetaOapg.properties.card_presence: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["cardholder_authentication_method"]) -> MetaOapg.properties.cardholder_authentication_method: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["country_code"]) -> MetaOapg.properties.country_code: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["is_installment"]) -> MetaOapg.properties.is_installment: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["is_recurring"]) -> MetaOapg.properties.is_recurring: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["pan_entry_mode"]) -> MetaOapg.properties.pan_entry_mode: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["partial_approval_capable"]) -> MetaOapg.properties.partial_approval_capable: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["pin_entry_mode"]) -> MetaOapg.properties.pin_entry_mode: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["pin_present"]) -> MetaOapg.properties.pin_present: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["purchase_amount_only"]) -> MetaOapg.properties.purchase_amount_only: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["terminal_attendance"]) -> MetaOapg.properties.terminal_attendance: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["terminal_id"]) -> MetaOapg.properties.terminal_id: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["terminal_location"]) -> MetaOapg.properties.terminal_location: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["terminal_type"]) -> MetaOapg.properties.terminal_type: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["zip"]) -> MetaOapg.properties.zip: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["card_data_input_capability", "card_holder_presence", "card_presence", "cardholder_authentication_method", "country_code", "is_installment", "is_recurring", "pan_entry_mode", "partial_approval_capable", "pin_entry_mode", "pin_present", "purchase_amount_only", "terminal_attendance", "terminal_id", "terminal_location", "terminal_type", "zip", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["card_data_input_capability"]) -> typing.Union[MetaOapg.properties.card_data_input_capability, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["card_holder_presence"]) -> typing.Union[MetaOapg.properties.card_holder_presence, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["card_presence"]) -> typing.Union[MetaOapg.properties.card_presence, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["cardholder_authentication_method"]) -> typing.Union[MetaOapg.properties.cardholder_authentication_method, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["country_code"]) -> typing.Union[MetaOapg.properties.country_code, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["is_installment"]) -> typing.Union[MetaOapg.properties.is_installment, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["is_recurring"]) -> typing.Union[MetaOapg.properties.is_recurring, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["pan_entry_mode"]) -> typing.Union[MetaOapg.properties.pan_entry_mode, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["partial_approval_capable"]) -> typing.Union[MetaOapg.properties.partial_approval_capable, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["pin_entry_mode"]) -> typing.Union[MetaOapg.properties.pin_entry_mode, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["pin_present"]) -> typing.Union[MetaOapg.properties.pin_present, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["purchase_amount_only"]) -> typing.Union[MetaOapg.properties.purchase_amount_only, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["terminal_attendance"]) -> typing.Union[MetaOapg.properties.terminal_attendance, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["terminal_id"]) -> typing.Union[MetaOapg.properties.terminal_id, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["terminal_location"]) -> typing.Union[MetaOapg.properties.terminal_location, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["terminal_type"]) -> typing.Union[MetaOapg.properties.terminal_type, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["zip"]) -> typing.Union[MetaOapg.properties.zip, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["card_data_input_capability", "card_holder_presence", "card_presence", "cardholder_authentication_method", "country_code", "is_installment", "is_recurring", "pan_entry_mode", "partial_approval_capable", "pin_entry_mode", "pin_present", "purchase_amount_only", "terminal_attendance", "terminal_id", "terminal_location", "terminal_type", "zip", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    card_data_input_capability: typing.Union[MetaOapg.properties.card_data_input_capability, str, schemas.Unset] = schemas.unset,
                    card_holder_presence: typing.Union[MetaOapg.properties.card_holder_presence, bool, schemas.Unset] = schemas.unset,
                    card_presence: typing.Union[MetaOapg.properties.card_presence, bool, schemas.Unset] = schemas.unset,
                    cardholder_authentication_method: typing.Union[MetaOapg.properties.cardholder_authentication_method, str, schemas.Unset] = schemas.unset,
                    country_code: typing.Union[MetaOapg.properties.country_code, str, schemas.Unset] = schemas.unset,
                    is_installment: typing.Union[MetaOapg.properties.is_installment, bool, schemas.Unset] = schemas.unset,
                    is_recurring: typing.Union[MetaOapg.properties.is_recurring, bool, schemas.Unset] = schemas.unset,
                    pan_entry_mode: typing.Union[MetaOapg.properties.pan_entry_mode, str, schemas.Unset] = schemas.unset,
                    partial_approval_capable: typing.Union[MetaOapg.properties.partial_approval_capable, bool, schemas.Unset] = schemas.unset,
                    pin_entry_mode: typing.Union[MetaOapg.properties.pin_entry_mode, str, schemas.Unset] = schemas.unset,
                    pin_present: typing.Union[MetaOapg.properties.pin_present, bool, schemas.Unset] = schemas.unset,
                    purchase_amount_only: typing.Union[MetaOapg.properties.purchase_amount_only, bool, schemas.Unset] = schemas.unset,
                    terminal_attendance: typing.Union[MetaOapg.properties.terminal_attendance, str, schemas.Unset] = schemas.unset,
                    terminal_id: typing.Union[MetaOapg.properties.terminal_id, str, schemas.Unset] = schemas.unset,
                    terminal_location: typing.Union[MetaOapg.properties.terminal_location, str, schemas.Unset] = schemas.unset,
                    terminal_type: typing.Union[MetaOapg.properties.terminal_type, str, schemas.Unset] = schemas.unset,
                    zip: typing.Union[MetaOapg.properties.zip, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'pos':
                    return super().__new__(
                        cls,
                        *_args,
                        card_data_input_capability=card_data_input_capability,
                        card_holder_presence=card_holder_presence,
                        card_presence=card_presence,
                        cardholder_authentication_method=cardholder_authentication_method,
                        country_code=country_code,
                        is_installment=is_installment,
                        is_recurring=is_recurring,
                        pan_entry_mode=pan_entry_mode,
                        partial_approval_capable=partial_approval_capable,
                        pin_entry_mode=pin_entry_mode,
                        pin_present=pin_present,
                        purchase_amount_only=purchase_amount_only,
                        terminal_attendance=terminal_attendance,
                        terminal_id=terminal_id,
                        terminal_location=terminal_location,
                        terminal_type=terminal_type,
                        zip=zip,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "card_id": card_id,
                "currency_code": currency_code,
                "currency_conversion": currency_conversion,
                "merchant": merchant,
                "network": network,
                "network_reference_id": network_reference_id,
                "pos": pos,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["card_id"]) -> MetaOapg.properties.card_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency_code"]) -> MetaOapg.properties.currency_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency_conversion"]) -> MetaOapg.properties.currency_conversion: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchant"]) -> MetaOapg.properties.merchant: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network_reference_id"]) -> MetaOapg.properties.network_reference_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pos"]) -> MetaOapg.properties.pos: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["card_id", "currency_code", "currency_conversion", "merchant", "network", "network_reference_id", "pos", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["card_id"]) -> typing.Union[MetaOapg.properties.card_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency_code"]) -> typing.Union[MetaOapg.properties.currency_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency_conversion"]) -> typing.Union[MetaOapg.properties.currency_conversion, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchant"]) -> typing.Union[MetaOapg.properties.merchant, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> typing.Union[MetaOapg.properties.network, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network_reference_id"]) -> typing.Union[MetaOapg.properties.network_reference_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pos"]) -> typing.Union[MetaOapg.properties.pos, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["card_id", "currency_code", "currency_conversion", "merchant", "network", "network_reference_id", "pos", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        card_id: typing.Union[MetaOapg.properties.card_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        currency_code: typing.Union[MetaOapg.properties.currency_code, str, schemas.Unset] = schemas.unset,
        currency_conversion: typing.Union[MetaOapg.properties.currency_conversion, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        merchant: typing.Union[MetaOapg.properties.merchant, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        network: typing.Union[MetaOapg.properties.network, str, schemas.Unset] = schemas.unset,
        network_reference_id: typing.Union[MetaOapg.properties.network_reference_id, str, schemas.Unset] = schemas.unset,
        pos: typing.Union[MetaOapg.properties.pos, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CardTransactionData':
        return super().__new__(
            cls,
            *_args,
            card_id=card_id,
            currency_code=currency_code,
            currency_conversion=currency_conversion,
            merchant=merchant,
            network=network,
            network_reference_id=network_reference_id,
            pos=pos,
            _configuration=_configuration,
            **kwargs,
        )



from synctera_client.paths.webhook_secrets.put import ApiForput
from synctera_client.paths.webhook_secrets.post import ApiForpost
from synctera_client.paths.webhook_secrets.delete import ApiFordelete


class WebhookSecrets(
    ApiForput,
    ApiForpost,
    ApiFordelete,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from synctera_client.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    ACCOUNTS = "/accounts"
    ACCOUNTS_PRODUCTS = "/accounts/products"
    ACCOUNTS_PRODUCTS_PRODUCT_ID = "/accounts/products/{product_id}"
    ACCOUNTS_TEMPLATES = "/accounts/templates"
    ACCOUNTS_TEMPLATES_TEMPLATE_ID = "/accounts/templates/{template_id}"
    ACCOUNTS_ACCOUNT_ID = "/accounts/{account_id}"
    ACCOUNTS_ACCOUNT_ID_RELATIONSHIPS = "/accounts/{account_id}/relationships"
    ACCOUNTS_ACCOUNT_ID_RELATIONSHIPS_RELATIONSHIP_ID = "/accounts/{account_id}/relationships/{relationship_id}"
    ACH = "/ach"
    ACH_TRANSACTION_SIMULATIONS_RECEIVING_RETURN = "/ach/transaction_simulations/receiving_return"
    ACH_TRANSACTION_SIMULATIONS_RECEIVING_TRANSACTION = "/ach/transaction_simulations/receiving_transaction"
    ACH_TRANSACTION_ID = "/ach/{transaction_id}"
    BUSINESSES = "/businesses"
    BUSINESSES_BUSINESS_ID = "/businesses/{business_id}"
    CARDS = "/cards"
    CARDS_ACTIVATE = "/cards/activate"
    CARDS_CARD_WIDGET_URL = "/cards/card_widget_url"
    CARDS_DIGITAL_WALLET_TOKENS = "/cards/digital_wallet_tokens"
    CARDS_DIGITAL_WALLET_TOKENS_DIGITAL_WALLET_TOKEN_ID = "/cards/digital_wallet_tokens/{digital_wallet_token_id}"
    CARDS_GATEWAYS = "/cards/gateways"
    CARDS_GATEWAYS_GATEWAY_ID = "/cards/gateways/{gateway_id}"
    CARDS_IMAGES = "/cards/images"
    CARDS_IMAGES_CARD_IMAGE_ID = "/cards/images/{card_image_id}"
    CARDS_IMAGES_CARD_IMAGE_ID_DATA = "/cards/images/{card_image_id}/data"
    CARDS_PRODUCTS = "/cards/products"
    CARDS_SINGLE_USE_TOKEN = "/cards/single_use_token"
    CARDS_TRANSACTION_SIMULATIONS_AUTHORIZATION = "/cards/transaction_simulations/authorization"
    CARDS_TRANSACTION_SIMULATIONS_AUTHORIZATION_ADVICE = "/cards/transaction_simulations/authorization/advice"
    CARDS_TRANSACTION_SIMULATIONS_CLEARING = "/cards/transaction_simulations/clearing"
    CARDS_TRANSACTION_SIMULATIONS_FINANCIAL = "/cards/transaction_simulations/financial"
    CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_ADVICE = "/cards/transaction_simulations/financial/advice"
    CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_BALANCE_INQUIRY = "/cards/transaction_simulations/financial/balance_inquiry"
    CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_ORIGINAL_CREDIT = "/cards/transaction_simulations/financial/original_credit"
    CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_WITHDRAWAL = "/cards/transaction_simulations/financial/withdrawal"
    CARDS_TRANSACTION_SIMULATIONS_REVERSAL = "/cards/transaction_simulations/reversal"
    CARDS_CARD_ID = "/cards/{card_id}"
    CARDS_CARD_ID_BARCODES = "/cards/{card_id}/barcodes"
    CARDS_CARD_ID_CHANGES = "/cards/{card_id}/changes"
    CARDS_CARD_ID_CLIENT_TOKEN = "/cards/{card_id}/client_token"
    CARDS_CARD_ID_DIGITAL_WALLET_TOKENS_APPLEPAY = "/cards/{card_id}/digital_wallet_tokens/applepay"
    CARDS_CARD_ID_DIGITAL_WALLET_TOKENS_GOOGLEPAY = "/cards/{card_id}/digital_wallet_tokens/googlepay"
    CARDS_CARD_ID_WEBHOOK_SIMULATIONS_FULFILLMENT = "/cards/{card_id}/webhook_simulations/fulfillment"
    CASH_PICKUPS = "/cash_pickups"
    CASH_PICKUPS_CASH_PICKUP_ID = "/cash_pickups/{cash_pickup_id}"
    CUSTOMERS = "/customers"
    CUSTOMERS_CUSTOMER_ID = "/customers/{customer_id}"
    CUSTOMERS_CUSTOMER_ID_DISCLOSURES = "/customers/{customer_id}/disclosures"
    CUSTOMERS_CUSTOMER_ID_EMPLOYMENT = "/customers/{customer_id}/employment"
    CUSTOMERS_CUSTOMER_ID_EMPLOYMENT_EMPLOYMENT_ID = "/customers/{customer_id}/employment/{employment_id}"
    CUSTOMERS_CUSTOMER_ID_PREFILL = "/customers/{customer_id}/prefill"
    CUSTOMERS_CUSTOMER_ID_RISK_RATINGS = "/customers/{customer_id}/risk_ratings"
    CUSTOMERS_CUSTOMER_ID_RISK_RATINGS_RISK_RATING_ID = "/customers/{customer_id}/risk_ratings/{risk_rating_id}"
    CUSTOMERS_CUSTOMER_ID_VERIFICATIONS = "/customers/{customer_id}/verifications"
    CUSTOMERS_CUSTOMER_ID_VERIFICATIONS_VERIFICATION_ID = "/customers/{customer_id}/verifications/{verification_id}"
    CUSTOMERS_CUSTOMER_ID_VERIFY = "/customers/{customer_id}/verify"
    CUSTOMERS_CUSTOMER_ID_WATCHLISTS_ALERTS = "/customers/{customer_id}/watchlists/alerts"
    CUSTOMERS_CUSTOMER_ID_WATCHLISTS_ALERTS_ALERT_ID = "/customers/{customer_id}/watchlists/alerts/{alert_id}"
    CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUBSCRIPTIONS = "/customers/{customer_id}/watchlists/subscriptions"
    CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUBSCRIPTIONS_SUBSCRIPTION_ID = "/customers/{customer_id}/watchlists/subscriptions/{subscription_id}"
    CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUPPRESSIONS = "/customers/{customer_id}/watchlists/suppressions"
    DISCLOSURES = "/disclosures"
    DISCLOSURES_DISCLOSURE_ID = "/disclosures/{disclosure_id}"
    DOCUMENTS = "/documents"
    DOCUMENTS_DOCUMENT_ID = "/documents/{document_id}"
    DOCUMENTS_DOCUMENT_ID_CONTENTS = "/documents/{document_id}/contents"
    DOCUMENTS_DOCUMENT_ID_VERSIONS = "/documents/{document_id}/versions"
    DOCUMENTS_DOCUMENT_ID_VERSIONS_DOCUMENT_VERSION = "/documents/{document_id}/versions/{document_version}"
    DOCUMENTS_DOCUMENT_ID_VERSIONS_DOCUMENT_VERSION_CONTENTS = "/documents/{document_id}/versions/{document_version}/contents"
    EXTERNAL_ACCOUNTS = "/external_accounts"
    EXTERNAL_ACCOUNTS_ACCESS_TOKENS = "/external_accounts/access_tokens"
    EXTERNAL_ACCOUNTS_ADD_VENDOR_ACCOUNTS = "/external_accounts/add_vendor_accounts"
    EXTERNAL_ACCOUNTS_LINK_TOKENS = "/external_accounts/link_tokens"
    EXTERNAL_ACCOUNTS_SYNC_VENDOR_ACCOUNTS = "/external_accounts/sync_vendor_accounts"
    EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID = "/external_accounts/{external_account_id}"
    EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID_BALANCE = "/external_accounts/{external_account_id}/balance"
    EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID_TRANSACTIONS = "/external_accounts/{external_account_id}/transactions"
    EXTERNAL_CARDS = "/external_cards"
    EXTERNAL_CARDS_TOKENS = "/external_cards/tokens"
    EXTERNAL_CARDS_TRANSFERS = "/external_cards/transfers"
    EXTERNAL_CARDS_TRANSFERS_TRANSFER_ID = "/external_cards/transfers/{transfer_id}"
    EXTERNAL_CARDS_TRANSFERS_TRANSFER_ID_REVERSALS = "/external_cards/transfers/{transfer_id}/reversals"
    EXTERNAL_CARDS_EXTERNAL_CARD_ID = "/external_cards/{external_card_id}"
    INTERNAL_ACCOUNTS = "/internal_accounts"
    INTERNAL_ACCOUNTS_INTERNAL_ACCOUNT_ID = "/internal_accounts/{internal_account_id}"
    MONITORING_ALERTS = "/monitoring/alerts"
    MONITORING_ALERTS_ALERT_ID = "/monitoring/alerts/{alert_id}"
    MONITORING_SUBSCRIPTIONS = "/monitoring/subscriptions"
    MONITORING_SUBSCRIPTIONS_SUBSCRIPTION_ID = "/monitoring/subscriptions/{subscription_id}"
    NOTES = "/notes"
    NOTES_NOTE_ID = "/notes/{note_id}"
    PAYMENT_SCHEDULES = "/payment_schedules"
    PAYMENT_SCHEDULES_PAYMENTS = "/payment_schedules/payments"
    PAYMENT_SCHEDULES_PAYMENT_SCHEDULE_ID = "/payment_schedules/{payment_schedule_id}"
    PERSONS = "/persons"
    PERSONS_PERSONAL_IDS = "/persons/personal_ids"
    PERSONS_PERSONAL_IDS_PERSONAL_ID_ID = "/persons/personal_ids/{personal_id_id}"
    PERSONS_PERSON_ID = "/persons/{person_id}"
    PERSONS_PERSON_ID_PREFILL = "/persons/{person_id}/prefill"
    RDC_DEPOSITS = "/rdc/deposits"
    RDC_DEPOSITS_DEPOSIT_ID = "/rdc/deposits/{deposit_id}"
    RELATIONSHIPS = "/relationships"
    RELATIONSHIPS_RELATIONSHIP_ID = "/relationships/{relationship_id}"
    SPEND_CONTROLS = "/spend_controls"
    SPEND_CONTROLS_SPEND_CONTROL_ID = "/spend_controls/{spend_control_id}"
    STATEMENTS = "/statements"
    STATEMENTS_STATEMENT_ID = "/statements/{statement_id}"
    STATEMENTS_STATEMENT_ID_TRANSACTIONS = "/statements/{statement_id}/transactions"
    TRANSACTIONS_INTERNAL_TRANSFER = "/transactions/internal_transfer"
    TRANSACTIONS_INTERNAL_TRANSFER_ID = "/transactions/internal_transfer/{id}"
    TRANSACTIONS_PENDING = "/transactions/pending"
    TRANSACTIONS_PENDING_ID = "/transactions/pending/{id}"
    TRANSACTIONS_POSTED = "/transactions/posted"
    TRANSACTIONS_POSTED_ID = "/transactions/posted/{id}"
    VERIFICATIONS = "/verifications"
    VERIFICATIONS_ADHOC = "/verifications/adhoc"
    VERIFICATIONS_VERIFY = "/verifications/verify"
    VERIFICATIONS_VERIFICATION_ID = "/verifications/{verification_id}"
    WEBHOOK_SECRETS = "/webhook_secrets"
    WEBHOOKS = "/webhooks"
    WEBHOOKS_TRIGGER = "/webhooks/trigger"
    WEBHOOKS_WEBHOOK_ID = "/webhooks/{webhook_id}"
    WEBHOOKS_WEBHOOK_ID_EVENTS = "/webhooks/{webhook_id}/events"
    WEBHOOKS_WEBHOOK_ID_EVENTS_EVENT_ID = "/webhooks/{webhook_id}/events/{event_id}"
    WEBHOOKS_WEBHOOK_ID_EVENTS_EVENT_ID_RESEND = "/webhooks/{webhook_id}/events/{event_id}/resend"
    WIPE = "/wipe"
    WIRES = "/wires"
    WIRES_WIRE_ID = "/wires/{wire_id}"



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class InternalTransferTransactionSubtypes(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The set of valid INTERNAL_TRANSFER transaction subtypes
    """


    class MetaOapg:
        enum_value_to_name = {
            "ACCOUNT_DECREASE_LIMIT": "ACCOUNT_DECREASE_LIMIT",
            "ACCOUNT_DECREASE_LIMIT_REVERSAL": "ACCOUNT_DECREASE_LIMIT_REVERSAL",
            "ACCOUNT_INCREASE_LIMIT": "ACCOUNT_INCREASE_LIMIT",
            "ACCOUNT_INCREASE_LIMIT_REVERSAL": "ACCOUNT_INCREASE_LIMIT_REVERSAL",
            "ACCOUNT_TO_ACCOUNT": "ACCOUNT_TO_ACCOUNT",
            "ACCOUNT_TO_ACCOUNT_REVERSAL": "ACCOUNT_TO_ACCOUNT_REVERSAL",
            "ACH_CREDIT_SWEEP": "ACH_CREDIT_SWEEP",
            "ACH_CREDIT_SWEEP_REVERSAL": "ACH_CREDIT_SWEEP_REVERSAL",
            "ACH_DEBIT_SWEEP": "ACH_DEBIT_SWEEP",
            "ACH_DEBIT_SWEEP_REVERSAL": "ACH_DEBIT_SWEEP_REVERSAL",
            "ACH_FLOAT_TRANSFER": "ACH_FLOAT_TRANSFER",
            "ACH_FLOAT_TRANSFER_REVERSAL": "ACH_FLOAT_TRANSFER_REVERSAL",
            "ACH_SWEEP": "ACH_SWEEP",
            "ACH_SWEEP_REVERSAL": "ACH_SWEEP_REVERSAL",
            "CASHBACK": "CASHBACK",
            "CASHBACK_REVERSAL": "CASHBACK_REVERSAL",
            "EXCHANGE_RATE_DIFFERENCE_GAIN": "EXCHANGE_RATE_DIFFERENCE_GAIN",
            "EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL": "EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL",
            "EXCHANGE_RATE_DIFFERENCE_LOSS": "EXCHANGE_RATE_DIFFERENCE_LOSS",
            "EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL": "EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL",
            "FEE": "FEE",
            "FEE_REVERSAL": "FEE_REVERSAL",
            "INCOMING_WIRE": "INCOMING_WIRE",
            "INCOMING_WIRE_REVERSAL": "INCOMING_WIRE_REVERSAL",
            "INTEREST_CHARGED": "INTEREST_CHARGED",
            "INTEREST_CHARGED_REVERSAL": "INTEREST_CHARGED_REVERSAL",
            "INTEREST_PAYOUT": "INTEREST_PAYOUT",
            "INTEREST_PAYOUT_REVERSAL": "INTEREST_PAYOUT_REVERSAL",
            "JIT_FUND": "JIT_FUND",
            "JIT_FUND_REVERSAL": "JIT_FUND_REVERSAL",
            "LOAN_DISBURSEMENT": "LOAN_DISBURSEMENT",
            "LOAN_DISBURSEMENT_REVERSAL": "LOAN_DISBURSEMENT_REVERSAL",
            "LOAN_FUNDING": "LOAN_FUNDING",
            "LOAN_FUNDING_REVERSAL": "LOAN_FUNDING_REVERSAL",
            "LOC_USAGE": "LOC_USAGE",
            "LOC_USAGE_REVERSAL": "LOC_USAGE_REVERSAL",
            "MANUAL_ADJUSTMENT": "MANUAL_ADJUSTMENT",
            "MANUAL_ADJUSTMENT_REVERSAL": "MANUAL_ADJUSTMENT_REVERSAL",
            "MANUAL_CARD_SWEEP": "MANUAL_CARD_SWEEP",
            "MANUAL_CARD_SWEEP_REVERSAL": "MANUAL_CARD_SWEEP_REVERSAL",
            "OUTGOING_INTERNATIONAL_REMITTANCE": "OUTGOING_INTERNATIONAL_REMITTANCE",
            "OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL": "OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL",
            "PROGRAM_DECREASE": "PROGRAM_DECREASE",
            "PROGRAM_DECREASE_REVERSAL": "PROGRAM_DECREASE_REVERSAL",
            "PROGRAM_EXPANSION": "PROGRAM_EXPANSION",
            "PROGRAM_EXPANSION_REVERSAL": "PROGRAM_EXPANSION_REVERSAL",
            "PROMOTIONAL_CREDIT": "PROMOTIONAL_CREDIT",
            "PROMOTIONAL_CREDIT_REVERSAL": "PROMOTIONAL_CREDIT_REVERSAL",
            "REPAYMENT": "REPAYMENT",
            "REPAYMENT_REVERSAL": "REPAYMENT_REVERSAL",
            "SIGN_UP_BONUS": "SIGN_UP_BONUS",
            "SIGN_UP_BONUS_REVERSAL": "SIGN_UP_BONUS_REVERSAL",
            "SUBSCRIPTION_FEE": "SUBSCRIPTION_FEE",
            "SUBSCRIPTION_FEE_REVERSAL": "SUBSCRIPTION_FEE_REVERSAL",
            "TRANSFER_FEE": "TRANSFER_FEE",
            "TRANSFER_FEE_REVERSAL": "TRANSFER_FEE_REVERSAL",
            "TRANSFER_FEE_REVERSAL_REVERSAL": "TRANSFER_FEE_REVERSAL_REVERSAL",
        }
    
    @schemas.classproperty
    def ACCOUNT_DECREASE_LIMIT(cls):
        return cls("ACCOUNT_DECREASE_LIMIT")
    
    @schemas.classproperty
    def ACCOUNT_DECREASE_LIMIT_REVERSAL(cls):
        return cls("ACCOUNT_DECREASE_LIMIT_REVERSAL")
    
    @schemas.classproperty
    def ACCOUNT_INCREASE_LIMIT(cls):
        return cls("ACCOUNT_INCREASE_LIMIT")
    
    @schemas.classproperty
    def ACCOUNT_INCREASE_LIMIT_REVERSAL(cls):
        return cls("ACCOUNT_INCREASE_LIMIT_REVERSAL")
    
    @schemas.classproperty
    def ACCOUNT_TO_ACCOUNT(cls):
        return cls("ACCOUNT_TO_ACCOUNT")
    
    @schemas.classproperty
    def ACCOUNT_TO_ACCOUNT_REVERSAL(cls):
        return cls("ACCOUNT_TO_ACCOUNT_REVERSAL")
    
    @schemas.classproperty
    def ACH_CREDIT_SWEEP(cls):
        return cls("ACH_CREDIT_SWEEP")
    
    @schemas.classproperty
    def ACH_CREDIT_SWEEP_REVERSAL(cls):
        return cls("ACH_CREDIT_SWEEP_REVERSAL")
    
    @schemas.classproperty
    def ACH_DEBIT_SWEEP(cls):
        return cls("ACH_DEBIT_SWEEP")
    
    @schemas.classproperty
    def ACH_DEBIT_SWEEP_REVERSAL(cls):
        return cls("ACH_DEBIT_SWEEP_REVERSAL")
    
    @schemas.classproperty
    def ACH_FLOAT_TRANSFER(cls):
        return cls("ACH_FLOAT_TRANSFER")
    
    @schemas.classproperty
    def ACH_FLOAT_TRANSFER_REVERSAL(cls):
        return cls("ACH_FLOAT_TRANSFER_REVERSAL")
    
    @schemas.classproperty
    def ACH_SWEEP(cls):
        return cls("ACH_SWEEP")
    
    @schemas.classproperty
    def ACH_SWEEP_REVERSAL(cls):
        return cls("ACH_SWEEP_REVERSAL")
    
    @schemas.classproperty
    def CASHBACK(cls):
        return cls("CASHBACK")
    
    @schemas.classproperty
    def CASHBACK_REVERSAL(cls):
        return cls("CASHBACK_REVERSAL")
    
    @schemas.classproperty
    def EXCHANGE_RATE_DIFFERENCE_GAIN(cls):
        return cls("EXCHANGE_RATE_DIFFERENCE_GAIN")
    
    @schemas.classproperty
    def EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL(cls):
        return cls("EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL")
    
    @schemas.classproperty
    def EXCHANGE_RATE_DIFFERENCE_LOSS(cls):
        return cls("EXCHANGE_RATE_DIFFERENCE_LOSS")
    
    @schemas.classproperty
    def EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL(cls):
        return cls("EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL")
    
    @schemas.classproperty
    def FEE(cls):
        return cls("FEE")
    
    @schemas.classproperty
    def FEE_REVERSAL(cls):
        return cls("FEE_REVERSAL")
    
    @schemas.classproperty
    def INCOMING_WIRE(cls):
        return cls("INCOMING_WIRE")
    
    @schemas.classproperty
    def INCOMING_WIRE_REVERSAL(cls):
        return cls("INCOMING_WIRE_REVERSAL")
    
    @schemas.classproperty
    def INTEREST_CHARGED(cls):
        return cls("INTEREST_CHARGED")
    
    @schemas.classproperty
    def INTEREST_CHARGED_REVERSAL(cls):
        return cls("INTEREST_CHARGED_REVERSAL")
    
    @schemas.classproperty
    def INTEREST_PAYOUT(cls):
        return cls("INTEREST_PAYOUT")
    
    @schemas.classproperty
    def INTEREST_PAYOUT_REVERSAL(cls):
        return cls("INTEREST_PAYOUT_REVERSAL")
    
    @schemas.classproperty
    def JIT_FUND(cls):
        return cls("JIT_FUND")
    
    @schemas.classproperty
    def JIT_FUND_REVERSAL(cls):
        return cls("JIT_FUND_REVERSAL")
    
    @schemas.classproperty
    def LOAN_DISBURSEMENT(cls):
        return cls("LOAN_DISBURSEMENT")
    
    @schemas.classproperty
    def LOAN_DISBURSEMENT_REVERSAL(cls):
        return cls("LOAN_DISBURSEMENT_REVERSAL")
    
    @schemas.classproperty
    def LOAN_FUNDING(cls):
        return cls("LOAN_FUNDING")
    
    @schemas.classproperty
    def LOAN_FUNDING_REVERSAL(cls):
        return cls("LOAN_FUNDING_REVERSAL")
    
    @schemas.classproperty
    def LOC_USAGE(cls):
        return cls("LOC_USAGE")
    
    @schemas.classproperty
    def LOC_USAGE_REVERSAL(cls):
        return cls("LOC_USAGE_REVERSAL")
    
    @schemas.classproperty
    def MANUAL_ADJUSTMENT(cls):
        return cls("MANUAL_ADJUSTMENT")
    
    @schemas.classproperty
    def MANUAL_ADJUSTMENT_REVERSAL(cls):
        return cls("MANUAL_ADJUSTMENT_REVERSAL")
    
    @schemas.classproperty
    def MANUAL_CARD_SWEEP(cls):
        return cls("MANUAL_CARD_SWEEP")
    
    @schemas.classproperty
    def MANUAL_CARD_SWEEP_REVERSAL(cls):
        return cls("MANUAL_CARD_SWEEP_REVERSAL")
    
    @schemas.classproperty
    def OUTGOING_INTERNATIONAL_REMITTANCE(cls):
        return cls("OUTGOING_INTERNATIONAL_REMITTANCE")
    
    @schemas.classproperty
    def OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL(cls):
        return cls("OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL")
    
    @schemas.classproperty
    def PROGRAM_DECREASE(cls):
        return cls("PROGRAM_DECREASE")
    
    @schemas.classproperty
    def PROGRAM_DECREASE_REVERSAL(cls):
        return cls("PROGRAM_DECREASE_REVERSAL")
    
    @schemas.classproperty
    def PROGRAM_EXPANSION(cls):
        return cls("PROGRAM_EXPANSION")
    
    @schemas.classproperty
    def PROGRAM_EXPANSION_REVERSAL(cls):
        return cls("PROGRAM_EXPANSION_REVERSAL")
    
    @schemas.classproperty
    def PROMOTIONAL_CREDIT(cls):
        return cls("PROMOTIONAL_CREDIT")
    
    @schemas.classproperty
    def PROMOTIONAL_CREDIT_REVERSAL(cls):
        return cls("PROMOTIONAL_CREDIT_REVERSAL")
    
    @schemas.classproperty
    def REPAYMENT(cls):
        return cls("REPAYMENT")
    
    @schemas.classproperty
    def REPAYMENT_REVERSAL(cls):
        return cls("REPAYMENT_REVERSAL")
    
    @schemas.classproperty
    def SIGN_UP_BONUS(cls):
        return cls("SIGN_UP_BONUS")
    
    @schemas.classproperty
    def SIGN_UP_BONUS_REVERSAL(cls):
        return cls("SIGN_UP_BONUS_REVERSAL")
    
    @schemas.classproperty
    def SUBSCRIPTION_FEE(cls):
        return cls("SUBSCRIPTION_FEE")
    
    @schemas.classproperty
    def SUBSCRIPTION_FEE_REVERSAL(cls):
        return cls("SUBSCRIPTION_FEE_REVERSAL")
    
    @schemas.classproperty
    def TRANSFER_FEE(cls):
        return cls("TRANSFER_FEE")
    
    @schemas.classproperty
    def TRANSFER_FEE_REVERSAL(cls):
        return cls("TRANSFER_FEE_REVERSAL")
    
    @schemas.classproperty
    def TRANSFER_FEE_REVERSAL_REVERSAL(cls):
        return cls("TRANSFER_FEE_REVERSAL_REVERSAL")



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Business(
    schemas.ComposedBase,
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Represents a business customer.
    """


    class MetaOapg:
        
        
        class all_of_0(
            schemas.AnyTypeSchema,
        ):
        
        
            class MetaOapg:
                required = {
                    "is_customer",
                    "status",
                }
        
            
            is_customer: schemas.AnyTypeSchema
            status: schemas.AnyTypeSchema
        
            def __new__(
                cls,
                *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'all_of_0':
                return super().__new__(
                    cls,
                    *_args,
                    _configuration=_configuration,
                    **kwargs,
                )
        
        @classmethod
        @functools.lru_cache()
        def all_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                cls.all_of_0,
                Base,
            ]


    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Business':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.base import Base



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class ExternalAccount(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "creation_time",
            "last_updated_time",
            "routing_identifiers",
            "account_owner_names",
            "id",
            "type",
            "account_identifiers",
            "verification",
            "status",
        }
        
        class properties:
        
            @staticmethod
            def account_identifiers() -> typing.Type['AccountIdentifiers']:
                return AccountIdentifiers
            
            
            class account_owner_names(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'account_owner_names':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            creation_time = schemas.DateTimeSchema
            id = schemas.UUIDSchema
            last_updated_time = schemas.DateTimeSchema
        
            @staticmethod
            def routing_identifiers() -> typing.Type['AccountRouting']:
                return AccountRouting
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def ACTIVE(cls):
                    return cls("ACTIVE")
                
                @schemas.classproperty
                def CLOSED(cls):
                    return cls("CLOSED")
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CHECKING(cls):
                    return cls("CHECKING")
                
                @schemas.classproperty
                def SAVINGS(cls):
                    return cls("SAVINGS")
                
                @schemas.classproperty
                def CREDIT_CARD(cls):
                    return cls("CREDIT_CARD")
                
                @schemas.classproperty
                def MONEY_MARKET(cls):
                    return cls("MONEY_MARKET")
                
                @schemas.classproperty
                def INVESTMENT_529(cls):
                    return cls("INVESTMENT_529")
                
                @schemas.classproperty
                def OTHER(cls):
                    return cls("OTHER")
        
            @staticmethod
            def verification() -> typing.Type['AccountVerification']:
                return AccountVerification
            business_id = schemas.UUIDSchema
            customer_id = schemas.UUIDSchema
            deletion_time = schemas.DateTimeSchema
            metadata = schemas.DictSchema
            name = schemas.StrSchema
            
            
            class nickname(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'nickname':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def vendor_data() -> typing.Type['ExternalAccountVendorData']:
                return ExternalAccountVendorData
        
            @staticmethod
            def vendor_info() -> typing.Type['VendorInfo']:
                return VendorInfo
            __annotations__ = {
                "account_identifiers": account_identifiers,
                "account_owner_names": account_owner_names,
                "creation_time": creation_time,
                "id": id,
                "last_updated_time": last_updated_time,
                "routing_identifiers": routing_identifiers,
                "status": status,
                "type": type,
                "verification": verification,
                "business_id": business_id,
                "customer_id": customer_id,
                "deletion_time": deletion_time,
                "metadata": metadata,
                "name": name,
                "nickname": nickname,
                "vendor_data": vendor_data,
                "vendor_info": vendor_info,
            }
    
    creation_time: MetaOapg.properties.creation_time
    last_updated_time: MetaOapg.properties.last_updated_time
    routing_identifiers: 'AccountRouting'
    account_owner_names: MetaOapg.properties.account_owner_names
    id: MetaOapg.properties.id
    type: MetaOapg.properties.type
    account_identifiers: 'AccountIdentifiers'
    verification: 'AccountVerification'
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_identifiers"]) -> 'AccountIdentifiers': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_owner_names"]) -> MetaOapg.properties.account_owner_names: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["routing_identifiers"]) -> 'AccountRouting': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verification"]) -> 'AccountVerification': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_id"]) -> MetaOapg.properties.business_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["deletion_time"]) -> MetaOapg.properties.deletion_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nickname"]) -> MetaOapg.properties.nickname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vendor_data"]) -> 'ExternalAccountVendorData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vendor_info"]) -> 'VendorInfo': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_identifiers", "account_owner_names", "creation_time", "id", "last_updated_time", "routing_identifiers", "status", "type", "verification", "business_id", "customer_id", "deletion_time", "metadata", "name", "nickname", "vendor_data", "vendor_info", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_identifiers"]) -> 'AccountIdentifiers': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_owner_names"]) -> MetaOapg.properties.account_owner_names: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["routing_identifiers"]) -> 'AccountRouting': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verification"]) -> 'AccountVerification': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_id"]) -> typing.Union[MetaOapg.properties.business_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> typing.Union[MetaOapg.properties.customer_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["deletion_time"]) -> typing.Union[MetaOapg.properties.deletion_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nickname"]) -> typing.Union[MetaOapg.properties.nickname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vendor_data"]) -> typing.Union['ExternalAccountVendorData', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vendor_info"]) -> typing.Union['VendorInfo', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_identifiers", "account_owner_names", "creation_time", "id", "last_updated_time", "routing_identifiers", "status", "type", "verification", "business_id", "customer_id", "deletion_time", "metadata", "name", "nickname", "vendor_data", "vendor_info", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, ],
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, ],
        routing_identifiers: 'AccountRouting',
        account_owner_names: typing.Union[MetaOapg.properties.account_owner_names, list, tuple, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        account_identifiers: 'AccountIdentifiers',
        verification: 'AccountVerification',
        status: typing.Union[MetaOapg.properties.status, str, ],
        business_id: typing.Union[MetaOapg.properties.business_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        deletion_time: typing.Union[MetaOapg.properties.deletion_time, str, datetime, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        nickname: typing.Union[MetaOapg.properties.nickname, None, str, schemas.Unset] = schemas.unset,
        vendor_data: typing.Union['ExternalAccountVendorData', schemas.Unset] = schemas.unset,
        vendor_info: typing.Union['VendorInfo', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ExternalAccount':
        return super().__new__(
            cls,
            *_args,
            creation_time=creation_time,
            last_updated_time=last_updated_time,
            routing_identifiers=routing_identifiers,
            account_owner_names=account_owner_names,
            id=id,
            type=type,
            account_identifiers=account_identifiers,
            verification=verification,
            status=status,
            business_id=business_id,
            customer_id=customer_id,
            deletion_time=deletion_time,
            metadata=metadata,
            name=name,
            nickname=nickname,
            vendor_data=vendor_data,
            vendor_info=vendor_info,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.account_identifiers import AccountIdentifiers
from synctera_client.model.account_routing import AccountRouting
from synctera_client.model.account_verification import AccountVerification
from synctera_client.model.external_account_vendor_data import ExternalAccountVendorData
from synctera_client.model.vendor_info import VendorInfo



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class TemplateFieldsGenericResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "account_type",
            "bank_country",
            "currency",
        }
        
        class properties:
        
            @staticmethod
            def account_type() -> typing.Type['AccountType']:
                return AccountType
            
            
            class bank_country(
                schemas.StrSchema
            ):
                pass
            
            
            class currency(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def balance_ceiling() -> typing.Type['BalanceCeiling']:
                return BalanceCeiling
        
            @staticmethod
            def balance_floor() -> typing.Type['BalanceFloor']:
                return BalanceFloor
        
            @staticmethod
            def billing_period() -> typing.Type['BillingPeriod']:
                return BillingPeriod
            
            
            class chargeoff_period(
                schemas.IntSchema
            ):
                pass
            
            
            class delinquency_period(
                schemas.IntSchema
            ):
                pass
            
            
            class fee_product_ids(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.UUIDSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'fee_product_ids':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class grace_period(
                schemas.IntSchema
            ):
                pass
            interest_product_id = schemas.UUIDSchema
            is_ach_enabled = schemas.BoolSchema
            is_card_enabled = schemas.BoolSchema
            is_external_card_enabled = schemas.BoolSchema
            is_p2p_enabled = schemas.BoolSchema
            is_sar_enabled = schemas.BoolSchema
            is_wire_enabled = schemas.BoolSchema
        
            @staticmethod
            def minimum_payment() -> typing.Type['MinimumPayment']:
                return MinimumPayment
            
            
            class overdraft_limit(
                schemas.Int64Schema
            ):
                pass
        
            @staticmethod
            def spend_control_ids() -> typing.Type['SpendControlIds']:
                return SpendControlIds
        
            @staticmethod
            def spending_limits() -> typing.Type['SpendingLimits']:
                return SpendingLimits
            __annotations__ = {
                "account_type": account_type,
                "bank_country": bank_country,
                "currency": currency,
                "balance_ceiling": balance_ceiling,
                "balance_floor": balance_floor,
                "billing_period": billing_period,
                "chargeoff_period": chargeoff_period,
                "delinquency_period": delinquency_period,
                "fee_product_ids": fee_product_ids,
                "grace_period": grace_period,
                "interest_product_id": interest_product_id,
                "is_ach_enabled": is_ach_enabled,
                "is_card_enabled": is_card_enabled,
                "is_external_card_enabled": is_external_card_enabled,
                "is_p2p_enabled": is_p2p_enabled,
                "is_sar_enabled": is_sar_enabled,
                "is_wire_enabled": is_wire_enabled,
                "minimum_payment": minimum_payment,
                "overdraft_limit": overdraft_limit,
                "spend_control_ids": spend_control_ids,
                "spending_limits": spending_limits,
            }
    
    account_type: 'AccountType'
    bank_country: MetaOapg.properties.bank_country
    currency: MetaOapg.properties.currency
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_type"]) -> 'AccountType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bank_country"]) -> MetaOapg.properties.bank_country: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance_ceiling"]) -> 'BalanceCeiling': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance_floor"]) -> 'BalanceFloor': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billing_period"]) -> 'BillingPeriod': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chargeoff_period"]) -> MetaOapg.properties.chargeoff_period: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["delinquency_period"]) -> MetaOapg.properties.delinquency_period: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fee_product_ids"]) -> MetaOapg.properties.fee_product_ids: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["grace_period"]) -> MetaOapg.properties.grace_period: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["interest_product_id"]) -> MetaOapg.properties.interest_product_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_ach_enabled"]) -> MetaOapg.properties.is_ach_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_card_enabled"]) -> MetaOapg.properties.is_card_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_external_card_enabled"]) -> MetaOapg.properties.is_external_card_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_p2p_enabled"]) -> MetaOapg.properties.is_p2p_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_sar_enabled"]) -> MetaOapg.properties.is_sar_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_wire_enabled"]) -> MetaOapg.properties.is_wire_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["minimum_payment"]) -> 'MinimumPayment': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["overdraft_limit"]) -> MetaOapg.properties.overdraft_limit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["spend_control_ids"]) -> 'SpendControlIds': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["spending_limits"]) -> 'SpendingLimits': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_type", "bank_country", "currency", "balance_ceiling", "balance_floor", "billing_period", "chargeoff_period", "delinquency_period", "fee_product_ids", "grace_period", "interest_product_id", "is_ach_enabled", "is_card_enabled", "is_external_card_enabled", "is_p2p_enabled", "is_sar_enabled", "is_wire_enabled", "minimum_payment", "overdraft_limit", "spend_control_ids", "spending_limits", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_type"]) -> 'AccountType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bank_country"]) -> MetaOapg.properties.bank_country: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance_ceiling"]) -> typing.Union['BalanceCeiling', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance_floor"]) -> typing.Union['BalanceFloor', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billing_period"]) -> typing.Union['BillingPeriod', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chargeoff_period"]) -> typing.Union[MetaOapg.properties.chargeoff_period, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["delinquency_period"]) -> typing.Union[MetaOapg.properties.delinquency_period, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fee_product_ids"]) -> typing.Union[MetaOapg.properties.fee_product_ids, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["grace_period"]) -> typing.Union[MetaOapg.properties.grace_period, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["interest_product_id"]) -> typing.Union[MetaOapg.properties.interest_product_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_ach_enabled"]) -> typing.Union[MetaOapg.properties.is_ach_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_card_enabled"]) -> typing.Union[MetaOapg.properties.is_card_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_external_card_enabled"]) -> typing.Union[MetaOapg.properties.is_external_card_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_p2p_enabled"]) -> typing.Union[MetaOapg.properties.is_p2p_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_sar_enabled"]) -> typing.Union[MetaOapg.properties.is_sar_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_wire_enabled"]) -> typing.Union[MetaOapg.properties.is_wire_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["minimum_payment"]) -> typing.Union['MinimumPayment', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["overdraft_limit"]) -> typing.Union[MetaOapg.properties.overdraft_limit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["spend_control_ids"]) -> typing.Union['SpendControlIds', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["spending_limits"]) -> typing.Union['SpendingLimits', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_type", "bank_country", "currency", "balance_ceiling", "balance_floor", "billing_period", "chargeoff_period", "delinquency_period", "fee_product_ids", "grace_period", "interest_product_id", "is_ach_enabled", "is_card_enabled", "is_external_card_enabled", "is_p2p_enabled", "is_sar_enabled", "is_wire_enabled", "minimum_payment", "overdraft_limit", "spend_control_ids", "spending_limits", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        account_type: 'AccountType',
        bank_country: typing.Union[MetaOapg.properties.bank_country, str, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        balance_ceiling: typing.Union['BalanceCeiling', schemas.Unset] = schemas.unset,
        balance_floor: typing.Union['BalanceFloor', schemas.Unset] = schemas.unset,
        billing_period: typing.Union['BillingPeriod', schemas.Unset] = schemas.unset,
        chargeoff_period: typing.Union[MetaOapg.properties.chargeoff_period, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        delinquency_period: typing.Union[MetaOapg.properties.delinquency_period, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        fee_product_ids: typing.Union[MetaOapg.properties.fee_product_ids, list, tuple, schemas.Unset] = schemas.unset,
        grace_period: typing.Union[MetaOapg.properties.grace_period, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        interest_product_id: typing.Union[MetaOapg.properties.interest_product_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        is_ach_enabled: typing.Union[MetaOapg.properties.is_ach_enabled, bool, schemas.Unset] = schemas.unset,
        is_card_enabled: typing.Union[MetaOapg.properties.is_card_enabled, bool, schemas.Unset] = schemas.unset,
        is_external_card_enabled: typing.Union[MetaOapg.properties.is_external_card_enabled, bool, schemas.Unset] = schemas.unset,
        is_p2p_enabled: typing.Union[MetaOapg.properties.is_p2p_enabled, bool, schemas.Unset] = schemas.unset,
        is_sar_enabled: typing.Union[MetaOapg.properties.is_sar_enabled, bool, schemas.Unset] = schemas.unset,
        is_wire_enabled: typing.Union[MetaOapg.properties.is_wire_enabled, bool, schemas.Unset] = schemas.unset,
        minimum_payment: typing.Union['MinimumPayment', schemas.Unset] = schemas.unset,
        overdraft_limit: typing.Union[MetaOapg.properties.overdraft_limit, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        spend_control_ids: typing.Union['SpendControlIds', schemas.Unset] = schemas.unset,
        spending_limits: typing.Union['SpendingLimits', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TemplateFieldsGenericResponse':
        return super().__new__(
            cls,
            *_args,
            account_type=account_type,
            bank_country=bank_country,
            currency=currency,
            balance_ceiling=balance_ceiling,
            balance_floor=balance_floor,
            billing_period=billing_period,
            chargeoff_period=chargeoff_period,
            delinquency_period=delinquency_period,
            fee_product_ids=fee_product_ids,
            grace_period=grace_period,
            interest_product_id=interest_product_id,
            is_ach_enabled=is_ach_enabled,
            is_card_enabled=is_card_enabled,
            is_external_card_enabled=is_external_card_enabled,
            is_p2p_enabled=is_p2p_enabled,
            is_sar_enabled=is_sar_enabled,
            is_wire_enabled=is_wire_enabled,
            minimum_payment=minimum_payment,
            overdraft_limit=overdraft_limit,
            spend_control_ids=spend_control_ids,
            spending_limits=spending_limits,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.account_type import AccountType
from synctera_client.model.balance_ceiling import BalanceCeiling
from synctera_client.model.balance_floor import BalanceFloor
from synctera_client.model.billing_period import BillingPeriod
from synctera_client.model.minimum_payment import MinimumPayment
from synctera_client.model.spend_control_ids import SpendControlIds
from synctera_client.model.spending_limits import SpendingLimits



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from synctera_client import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401

from synctera_client.model.error import Error
from synctera_client.model.external_accounts_list import ExternalAccountsList

from . import path

# Query params


class CustomerIdSchema(
    schemas.ListSchema
):


    class MetaOapg:
        items = schemas.UUIDSchema

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CustomerIdSchema':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)


class BusinessIdSchema(
    schemas.ListSchema
):


    class MetaOapg:
        items = schemas.UUIDSchema

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'BusinessIdSchema':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)


class LimitSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 1
PageTokenSchema = schemas.StrSchema
PartnerOwnershipSchema = schemas.StrSchema
IncludeHistorySchema = schemas.BoolSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'customer_id': typing.Union[CustomerIdSchema, list, tuple, ],
        'business_id': typing.Union[BusinessIdSchema, list, tuple, ],
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'page_token': typing.Union[PageTokenSchema, str, ],
        'partner_ownership': typing.Union[PartnerOwnershipSchema, str, ],
        'include_history': typing.Union[IncludeHistorySchema, bool, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_customer_id = api_client.QueryParameter(
    name="customer_id",
    style=api_client.ParameterStyle.FORM,
    schema=CustomerIdSchema,
)
request_query_business_id = api_client.QueryParameter(
    name="business_id",
    style=api_client.ParameterStyle.FORM,
    schema=BusinessIdSchema,
)
request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_page_token = api_client.QueryParameter(
    name="page_token",
    style=api_client.ParameterStyle.FORM,
    schema=PageTokenSchema,
    explode=True,
)
request_query_partner_ownership = api_client.QueryParameter(
    name="partner_ownership",
    style=api_client.ParameterStyle.FORM,
    schema=PartnerOwnershipSchema,
    explode=True,
)
request_query_include_history = api_client.QueryParameter(
    name="include_history",
    style=api_client.ParameterStyle.FORM,
    schema=IncludeHistorySchema,
    explode=True,
)
_auth = [
    'bearerAuth',
]
SchemaFor200ResponseBodyApplicationJson = ExternalAccountsList


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor401ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationProblemjson),
    },
)
SchemaFor403ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor403(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor403ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_403 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor403,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor403ResponseBodyApplicationProblemjson),
    },
)
SchemaFor500ResponseBodyApplicationProblemjson = Error


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor500ResponseBodyApplicationProblemjson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
    content={
        'application/problem+json': api_client.MediaType(
            schema=SchemaFor500ResponseBodyApplicationProblemjson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '401': _response_for_401,
    '403': _response_for_403,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
    'application/problem+json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _list_external_accounts_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _list_external_accounts_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _list_external_accounts_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _list_external_accounts_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        List external accounts
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_customer_id,
            request_query_business_id,
            request_query_limit,
            request_query_page_token,
            request_query_partner_ownership,
            request_query_include_history,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class ListExternalAccounts(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def list_external_accounts(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def list_external_accounts(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def list_external_accounts(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def list_external_accounts(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._list_external_accounts_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._list_external_accounts_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class CardProduct(
    schemas.ComposedSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Card Product
    """


    class MetaOapg:
        
        
        class all_of_1(
            schemas.DictSchema
        ):
        
        
            class MetaOapg:
                required = {
                    "card_program_id",
                    "name",
                    "active",
                    "start_date",
                }
                
                class properties:
                    active = schemas.BoolSchema
                    card_program_id = schemas.UUIDSchema
                    
                    
                    class color(
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            regex=[{
                                'pattern': r'^[0-9A-F]{6}$',  # noqa: E501
                            }]
                    creation_time = schemas.DateTimeSchema
                
                    @staticmethod
                    def digital_wallet_tokenization() -> typing.Type['DigitalWalletTokenization']:
                        return DigitalWalletTokenization
                    end_date = schemas.DateTimeSchema
                    id = schemas.UUIDSchema
                    image = schemas.BoolSchema
                
                    @staticmethod
                    def image_mode() -> typing.Type['CardImageMode']:
                        return CardImageMode
                    issue_without_kyc = schemas.BoolSchema
                    last_modified_time = schemas.DateTimeSchema
                    
                    
                    class name(
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            max_length = 40
                            min_length = 1
                    
                    
                    class orientation(
                        schemas.EnumBase,
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            enum_value_to_name = {
                                "HORIZONTAL": "HORIZONTAL",
                                "VERTICAL": "VERTICAL",
                            }
                        
                        @schemas.classproperty
                        def HORIZONTAL(cls):
                            return cls("HORIZONTAL")
                        
                        @schemas.classproperty
                        def VERTICAL(cls):
                            return cls("VERTICAL")
                    
                    
                    class package_id(
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            max_length = 50
                            min_length = 1
                
                    @staticmethod
                    def physical_card_format() -> typing.Type['PhysicalCardFormat']:
                        return PhysicalCardFormat
                
                    @staticmethod
                    def return_address() -> typing.Type['Shipping']:
                        return Shipping
                    start_date = schemas.DateTimeSchema
                
                    @staticmethod
                    def three_ds_policy() -> typing.Type['ThreeDsPolicy']:
                        return ThreeDsPolicy
                
                    @staticmethod
                    def txn_enhancer() -> typing.Type['TxnEnhancer']:
                        return TxnEnhancer
                    __annotations__ = {
                        "active": active,
                        "card_program_id": card_program_id,
                        "color": color,
                        "creation_time": creation_time,
                        "digital_wallet_tokenization": digital_wallet_tokenization,
                        "end_date": end_date,
                        "id": id,
                        "image": image,
                        "image_mode": image_mode,
                        "issue_without_kyc": issue_without_kyc,
                        "last_modified_time": last_modified_time,
                        "name": name,
                        "orientation": orientation,
                        "package_id": package_id,
                        "physical_card_format": physical_card_format,
                        "return_address": return_address,
                        "start_date": start_date,
                        "three_ds_policy": three_ds_policy,
                        "txn_enhancer": txn_enhancer,
                    }
            
            card_program_id: MetaOapg.properties.card_program_id
            name: MetaOapg.properties.name
            active: MetaOapg.properties.active
            start_date: MetaOapg.properties.start_date
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["active"]) -> MetaOapg.properties.active: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["card_program_id"]) -> MetaOapg.properties.card_program_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["color"]) -> MetaOapg.properties.color: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["digital_wallet_tokenization"]) -> 'DigitalWalletTokenization': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["end_date"]) -> MetaOapg.properties.end_date: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["image"]) -> MetaOapg.properties.image: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["image_mode"]) -> 'CardImageMode': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["issue_without_kyc"]) -> MetaOapg.properties.issue_without_kyc: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["last_modified_time"]) -> MetaOapg.properties.last_modified_time: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["orientation"]) -> MetaOapg.properties.orientation: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["package_id"]) -> MetaOapg.properties.package_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["physical_card_format"]) -> 'PhysicalCardFormat': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["return_address"]) -> 'Shipping': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["start_date"]) -> MetaOapg.properties.start_date: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["three_ds_policy"]) -> 'ThreeDsPolicy': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["txn_enhancer"]) -> 'TxnEnhancer': ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["active", "card_program_id", "color", "creation_time", "digital_wallet_tokenization", "end_date", "id", "image", "image_mode", "issue_without_kyc", "last_modified_time", "name", "orientation", "package_id", "physical_card_format", "return_address", "start_date", "three_ds_policy", "txn_enhancer", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["active"]) -> MetaOapg.properties.active: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["card_program_id"]) -> MetaOapg.properties.card_program_id: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["color"]) -> typing.Union[MetaOapg.properties.color, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["digital_wallet_tokenization"]) -> typing.Union['DigitalWalletTokenization', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["end_date"]) -> typing.Union[MetaOapg.properties.end_date, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["image"]) -> typing.Union[MetaOapg.properties.image, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["image_mode"]) -> typing.Union['CardImageMode', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["issue_without_kyc"]) -> typing.Union[MetaOapg.properties.issue_without_kyc, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["last_modified_time"]) -> typing.Union[MetaOapg.properties.last_modified_time, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["orientation"]) -> typing.Union[MetaOapg.properties.orientation, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["package_id"]) -> typing.Union[MetaOapg.properties.package_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["physical_card_format"]) -> typing.Union['PhysicalCardFormat', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["return_address"]) -> typing.Union['Shipping', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["start_date"]) -> MetaOapg.properties.start_date: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["three_ds_policy"]) -> typing.Union['ThreeDsPolicy', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["txn_enhancer"]) -> typing.Union['TxnEnhancer', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["active", "card_program_id", "color", "creation_time", "digital_wallet_tokenization", "end_date", "id", "image", "image_mode", "issue_without_kyc", "last_modified_time", "name", "orientation", "package_id", "physical_card_format", "return_address", "start_date", "three_ds_policy", "txn_enhancer", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *_args: typing.Union[dict, frozendict.frozendict, ],
                card_program_id: typing.Union[MetaOapg.properties.card_program_id, str, uuid.UUID, ],
                name: typing.Union[MetaOapg.properties.name, str, ],
                active: typing.Union[MetaOapg.properties.active, bool, ],
                start_date: typing.Union[MetaOapg.properties.start_date, str, datetime, ],
                color: typing.Union[MetaOapg.properties.color, str, schemas.Unset] = schemas.unset,
                creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
                digital_wallet_tokenization: typing.Union['DigitalWalletTokenization', schemas.Unset] = schemas.unset,
                end_date: typing.Union[MetaOapg.properties.end_date, str, datetime, schemas.Unset] = schemas.unset,
                id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                image: typing.Union[MetaOapg.properties.image, bool, schemas.Unset] = schemas.unset,
                image_mode: typing.Union['CardImageMode', schemas.Unset] = schemas.unset,
                issue_without_kyc: typing.Union[MetaOapg.properties.issue_without_kyc, bool, schemas.Unset] = schemas.unset,
                last_modified_time: typing.Union[MetaOapg.properties.last_modified_time, str, datetime, schemas.Unset] = schemas.unset,
                orientation: typing.Union[MetaOapg.properties.orientation, str, schemas.Unset] = schemas.unset,
                package_id: typing.Union[MetaOapg.properties.package_id, str, schemas.Unset] = schemas.unset,
                physical_card_format: typing.Union['PhysicalCardFormat', schemas.Unset] = schemas.unset,
                return_address: typing.Union['Shipping', schemas.Unset] = schemas.unset,
                three_ds_policy: typing.Union['ThreeDsPolicy', schemas.Unset] = schemas.unset,
                txn_enhancer: typing.Union['TxnEnhancer', schemas.Unset] = schemas.unset,
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'all_of_1':
                return super().__new__(
                    cls,
                    *_args,
                    card_program_id=card_program_id,
                    name=name,
                    active=active,
                    start_date=start_date,
                    color=color,
                    creation_time=creation_time,
                    digital_wallet_tokenization=digital_wallet_tokenization,
                    end_date=end_date,
                    id=id,
                    image=image,
                    image_mode=image_mode,
                    issue_without_kyc=issue_without_kyc,
                    last_modified_time=last_modified_time,
                    orientation=orientation,
                    package_id=package_id,
                    physical_card_format=physical_card_format,
                    return_address=return_address,
                    three_ds_policy=three_ds_policy,
                    txn_enhancer=txn_enhancer,
                    _configuration=_configuration,
                    **kwargs,
                )
        
        @classmethod
        @functools.lru_cache()
        def all_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                CardFormat,
                cls.all_of_1,
            ]


    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CardProduct':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.card_format import CardFormat
from synctera_client.model.card_image_mode import CardImageMode
from synctera_client.model.digital_wallet_tokenization import DigitalWalletTokenization
from synctera_client.model.physical_card_format import PhysicalCardFormat
from synctera_client.model.shipping import Shipping
from synctera_client.model.three_ds_policy import ThreeDsPolicy
from synctera_client.model.txn_enhancer import TxnEnhancer



from synctera_client.paths.customers_customer_id.get import ApiForget
from synctera_client.paths.customers_customer_id.put import ApiForput
from synctera_client.paths.customers_customer_id.patch import ApiForpatch


class CustomersCustomerId(
    ApiForget,
    ApiForput,
    ApiForpatch,
):
    pass



from synctera_client.paths.external_cards_transfers.get import ApiForget
from synctera_client.paths.external_cards_transfers.post import ApiForpost


class ExternalCardsTransfers(
    ApiForget,
    ApiForpost,
):
    pass



from synctera_client.paths.accounts_templates.get import ApiForget
from synctera_client.paths.accounts_templates.post import ApiForpost


class AccountsTemplates(
    ApiForget,
    ApiForpost,
):
    pass
